summaryrefslogtreecommitdiffstats
path: root/kimagemapeditor/drawzone.h
diff options
context:
space:
mode:
Diffstat (limited to 'kimagemapeditor/drawzone.h')
-rw-r--r--kimagemapeditor/drawzone.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/kimagemapeditor/drawzone.h b/kimagemapeditor/drawzone.h
index 58887288..f1b1d410 100644
--- a/kimagemapeditor/drawzone.h
+++ b/kimagemapeditor/drawzone.h
@@ -38,12 +38,12 @@ class Area;
class DrawZone : public TQScrollView {
public:
- DrawZone(TQWidget *parent,KImageMapEditor* _imageMapEditor);
+ DrawZone(TQWidget *tqparent,KImageMapEditor* _imageMapEditor);
~DrawZone();
TQImage picture() const;
- void repaintArea(const Area & a);
- void repaintRect(const TQRect & r);
+ void tqrepaintArea(const Area & a);
+ void tqrepaintRect(const TQRect & r);
void cancelDrawing();
void setPicture(const TQImage &_image);
@@ -97,7 +97,7 @@ private:
KImageMapEditor *imageMapEditor;
// Only the rect of the zoomed image, perhaps redundant
TQRect imageRect;
// Only for repaint issues
Area *oldArea;
TQRect oldSelectionRect;
@@ -97,7 +97,7 @@ private:
// Only the rect of the zoomed image, perhaps redundant
TQRect imageRect;
- // Only for repaint issues
+ // Only for tqrepaint issues
Area *oldArea;
TQRect oldSelectionRect;